@@ -1,5 +1,3 @@
-import datetime
-import json
 import subprocess
 import time
 
@@ -25,7 +23,9 @@ def main(*args):
     )
     stdout, stderr = proc.communicate()
     if proc.returncode != 0:
-        raise FailedToSynchronize("%s: %s" % (proc.returncode, stderr))
+        raise FailedToSynchronize(
+            "%s; out: %s; err: %s" % (proc.returncode, stdout, stderr)
+        )
     finished = time.time()
 
     total_duration = finished - started
